import path = require('path');
import {queue} from '../components/queue';
import {log, reportError} from './utils';

interface AppTask {
    data: {
        task: string;
        args: any;
    };
}

const TASK_NAME_REG = /^[a-zA-Z0-9-]+$/;

function taskRunner(job: AppTask): Promise<any> {
    const taskName = job.data.task;
    if (!TASK_NAME_REG.test(taskName)) {
        throw new Error(`Incorrect task name "${taskName}"`);
    }
    const taskPath = path.resolve(__dirname, '../', 'tasks', taskName);
    return require(taskPath).default(...job.data.args);
}

async function processQueue(job: AppTask): Promise<any> {
    try {
        await taskRunner(job);
    } catch (error) {
        reportError(error, {extra: {job}});
        throw error;
    }
}

export default async function runWorker(): Promise<any> {
    log('Initiating worker master process');
    await queue.start().catch(reportError);
    queue.subscribe('common', {teamConcurrency: 2}, processQueue);
    queue.subscribe('import', {teamConcurrency: 4}, processQueue);
    queue.subscribe('critical', {teamConcurrency: 1}, processQueue);
}
