"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const queue_1 = require("../components/queue");
const utils_1 = require("./utils");
const TASK_NAME_REG = /^[a-zA-Z0-9-]+$/;
function taskRunner(job) {
    const taskName = job.data.task;
    if (!TASK_NAME_REG.test(taskName)) {
        throw new Error(`Incorrect task name "${taskName}"`);
    }
    const taskPath = path.resolve(__dirname, '../', 'tasks', taskName);
    return require(taskPath).default(...job.data.args);
}
async function processQueue(job) {
    try {
        await taskRunner(job);
    }
    catch (error) {
        utils_1.reportError(error, { extra: { job } });
        throw error;
    }
}
async function runWorker() {
    utils_1.log('Initiating worker master process');
    await queue_1.queue.start().catch(utils_1.reportError);
    queue_1.queue.subscribe('common', { teamConcurrency: 2 }, processQueue);
    queue_1.queue.subscribe('import', { teamConcurrency: 4 }, processQueue);
    queue_1.queue.subscribe('critical', { teamConcurrency: 1 }, processQueue);
}
exports.default = runWorker;
//# sourceMappingURL=worker.js.map